#ifndef NT2_INCLUDE_FUNCTIONS_OFSAMEHEIGHT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_OFSAMEHEIGHT_HPP_INCLUDED

#include <nt2/predicates/include/functions/ofsameheight.hpp>

#endif
